==> segatex-6.50.tgz: segatex-6.50/downloader/downloader.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 * shintaro.fujiwara@gmail.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */
#include <qmessagebox.h>

#include "downloader.h"

Downloader::Downloader(const QUrl &url, QString version)
{
    if (url.protocol() != "ftp") {
        QMessageBox::warning(0, tr("Downloader"),
                             tr("Protocol must be 'ftp'."));
        emit finished();
        return;
    }

    int port = 21;
    if (url.hasPort())
        port = url.port();

    //connect(&ftp, SIGNAL(done(bool)),
     //       this, SLOT(ftpDone(bool)));
    connect(&ftp, SIGNAL(listInfo(const QUrlInfo &)),
            this, SLOT(listInfo(const QUrlInfo &)));

	ftp.connectToHost(url.host(), port);
	//ftp.connectToHost("ftp.riken.jp");
	//ftp.login("anonymous","test@com");
	ftp.login();
	if(url.host() == "ftp.riken.jp"){
		if(version == "seven")
			ftp.cd("Linux/fedora/releases/7/Fedora/i386/iso");
		if(version == "eight")
			ftp.cd("Linux/fedora/releases/8/Fedora/i386/iso");
		if(version == "nine")
			ftp.cd("Linux/fedora/releases/9/Fedora/i386/iso");
	}
	if(url.host() == "mirrors.usc.edu"){
		if(version == "seven")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/7/Fedora/i386/iso");
		if(version == "eight")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/8/Fedora/i386/iso");
		if(version == "nine")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/9/Fedora/i386/iso");
	}
	ftp.list();
}

void Downloader::listInfo(const QUrlInfo &urlInfo)
{
    if (urlInfo.isFile() && urlInfo.isReadable()) {
        QFile *file = new QFile(urlInfo.name());
        if (!file->open(IO_WriteOnly)) {
            QMessageBox::warning(0, tr("Downloader"),
                                 tr("Error: Cannot open file "
                                    "%1:\n%2.")
                                 .arg(file->name())
                                 .arg(file->errorString()));
            emit finished();
            return;
        }

        ftp.get(urlInfo.name(), file);
        openedFiles.push_back(file);
    }
}

void Downloader::ftpDone(bool error)
{
    if (error)
        QMessageBox::warning(0, tr("Downloader"),
                             tr("Error: %1.")
                             .arg(ftp.errorString()));

    for (int i = 0; i < (int)openedFiles.size(); ++i)
        delete openedFiles[i];
    emit finished();
}

==> segatex-7.76.tgz: segatex-7.76/downloader/downloader.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2009 Shintaro Fujiwara 
 * shintaro.fujiwara@gmail.com
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */
#include <qmessagebox.h>

#include "downloader.h"

Downloader::Downloader(const QUrl &url, QString version)
{
    //if (url.protocol() != "ftp") {
    if (url.scheme() != "ftp") {
        QMessageBox::warning(0, tr("Downloader"),
                             tr("Protocol must be 'ftp'."));
        emit finished();
        return;
    }

    int port = 21;
    //if (url.hasPort())
    if (url.port() != -1)
        port = url.port();

    //connect(&ftp, SIGNAL(done(bool)),
     //       this, SLOT(ftpDone(bool)));
    connect(&ftp, SIGNAL(listInfo(const QUrlInfo &)),
            this, SLOT(listInfo(const QUrlInfo &)));

	ftp.connectToHost(url.host(), port);
	//ftp.connectToHost("ftp.riken.jp");
	//ftp.login("anonymous","test@com");
	ftp.login();
	if(url.host() == "ftp.riken.jp"){
		/*
		if(version == "seven")
			ftp.cd("Linux/fedora/releases/7/Fedora/i386/iso");
		*/
		if(version == "eight")
			ftp.cd("Linux/fedora/releases/8/Fedora/i386/iso");
		if(version == "nine")
			ftp.cd("Linux/fedora/releases/9/Fedora/i386/iso");
		if(version == "ten")
			ftp.cd("Linux/fedora/releases/10/Fedora/i386/iso");
	}
	if(url.host() == "mirrors.usc.edu"){
		/*
		if(version == "seven")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/7/Fedora/i386/iso");
		*/
		if(version == "eight")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/8/Fedora/i386/iso");
		if(version == "nine")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/9/Fedora/i386/iso");
		if(version == "ten")
			ftp.cd("pub/linux/distributions/fedora/linux/releases/10/Fedora/i386/iso");
	}
	ftp.list();
}

void Downloader::listInfo(const QUrlInfo &urlInfo)
{
    if (urlInfo.isFile() && urlInfo.isReadable()) {
        QFile *file = new QFile(urlInfo.name());
        if (!file->open(QIODevice::WriteOnly)) {
            QMessageBox::warning(0, tr("Downloader"),
                                 tr("Error: Cannot open file "
                                    "%1:\n%2.")
                                 //.arg(file->name())
                                 .arg(file->fileName())
                                 .arg(file->errorString()));
            emit finished();
            return;
        }

        ftp.get(urlInfo.name(), file);
        openedFiles.push_back(file);
    }
}

void Downloader::ftpDone(bool error)
{
    if (error)
        QMessageBox::warning(0, tr("Downloader"),
                             tr("Error: %1.")
                             .arg(ftp.errorString()));

    for (int i = 0; i < (int)openedFiles.size(); ++i)
        delete openedFiles[i];
    emit finished();
}
